/*

** PURPOSE: 	This do-file calculates the results of the Malawi BRIE program 
				
		Variables used in the analysis:
			We convert all outcomes so that the sign of all of the variables in a family goes in the same direction.
			The prefix:
			F_ added to the beginning of a var name indicates that the var has follow-up and baseline info according to the specific round survey.
			vars wihouth prefix correspond to vars with baseline info, unless otherwise noted.
			missBS added to the beginning of a var name indicates the missings at baseline of that var.
			missF added to the beginning of a var name indicates the missings at each follow-up and baseline of that var.
			
		Table 2: Verification of randomization
		Table 3: Take-up analysis
		
		IMPACT ANALYSIS: (firms no attrition and round_fup!=0)
		Table 4: Impacts on Formalization
		Table 5: Gender Heterogeneity in Impacts on Formalization
		Table 6: Impacts on Business Performance
		Table 7: Gender Heterogeneity in Impacts on Business Performance
		Table 8: Channels of impacts on firms
		Table 9: Impacts on Use of Finance
		Table 10: Impacts on Taxes and Trust in the State

		APPENDIX
		Table A1: Descriptive information at baseline
		Table A2: Attrition and Business Closure
		Table A3: Impacts over time on having BRC 
		Table A4: Impacts on Access to Financial services


		Q-VALUES
		Sharpened q-values for all regressions are runned using False Discovery Risk (FDR).
		We follow Benjamin and Hochberg (1995) and Fink, McConnell, and Vollmer (2012)
		They are estimated below each regression. They are exported in a different matrix than the regression output.

				
** REQUIRES: 	"...\BRIE_finalpanel_Allfollowups_XXX2018.dta" [Master with all clean data sets for baseline + 4 follow ups]

*/


clear
clear matrix
clear mata
set matsize 5000
set more off
set maxvar 30000
version 10.1



** Directory

cap cd "C:\Users\Adriana\Dropbox\World Bank\Malawi\BRIE box"

global data		"Paper for pub\Data"
global analysis		"Paper for pub\temp"

* Open data
use "$data\BRIE_finalpanel_Allfollowups_SEP2018.dta", clear

* Tables

*** Table 2
* RANDOMIZATION TEST: comparison of means by treatment status

* Baseline variables

#d ;
local BS_descriptive female lilongwe large_size firm_age high_capture Manufacturing Retail Services  					/* Strata vars */
Total_workers2 Business_owner owner_started own_space innov electricity_access Num_competitors time_to_nearestbank  	/* Firm Characteristics */
owner_age Married hh_decision_index  Selfmainprovider Literate primary_completed 
Seconday_completed Higher_education high_capture Financial_knowledge mother_enterpreneur 
mother_wage_employt father_enterpreneur father_wage_employt spouse_enterpreneur spouse_wage_employt   					/* Individual Characteristics */
has_TPIN has_city_council usd_Revenue_lastweek99 usd_Revenue_lastmonth99 usd_Profit_lastweek99 usd_Profit_lastmonth99  /* Primary outcomes */
Total_workers2 number_days_workmonth usd_capital usd_assets propmaleworkers  			  /* Secondary outcomes*/
borrowed_in_past usd_amount_recentloan banks_any_account banksonly_bus_account account_used_only_business save_home 
rosca_sacco banks_saving usd_saved_amount usd_saved_amount_bank mix_bus_hh                /*Mechanisms of change: Access to finance	*/
benefits_reg inspected_municipality Asked_for_bribe threats_to_shutdown 
confiscation sexually_harassed other_harassment receipt  num_customers tender budget financial_records advert  other_activity   /*Mechanism of change: Other potential benefits of formalization */
;
#d cr 


foreach treat of var treat1_BR treat2_BR_TPIN treat3_BR_Bank {

capture matrix drop Table2_`treat'
capture matrix drop Table2_Control

foreach var of varlist `BS_descriptive' {

preserve

quietly keep if `treat'==1 | control==1

scalar drop _all

quietly sum `var' if round_fup==0 /* baseline descriptives*/

quietly scalar bin`var' = r(min) + r(max) 

if bin`var'==1 {

quietly ttest `var', by(`treat')

quietly scalar mean1`var' =  round(r(mu_1)*100,.01)   /* control group */

quietly scalar mean2`var' =  round(r(mu_2)*100,.01)  /* treat group */

}

 

else {

quietly ttest `var', by(`treat')

quietly scalar mean1`var' =  round(r(mu_1),.01)  /* control group */

quietly scalar mean2`var' =  round(r(mu_2),.01) /* treat group */
}

quietly matrix Table2_`treat'= nullmat(Table2_`treat') \ [mean2`var']
quietly matrix Table2_Control= nullmat(Table2_Control) \ [mean1`var']

restore
}

* Columns and rows names

quietly matrix rownames Table2_`treat' = `BS_descriptive'
quietly matrix colnames Table2_`treat' = `treat' 
quietly matrix colnames Table2_Control = Control

}

* F-test
* Verification of randomization at baseline
* var = a + b*Treat1+c*Treat2+d*Treat3 + error 
* F-test: Treat1==Treat2==Treat3==0
foreach var of varlist `BS_descriptive' {

reg `var' treat1_BR treat2_BR_TPIN treat3_BR_Bank if round_fup==0 , cluster(id) robust  /* baseline descriptives*/ 

matrix coeff`var'= e(b)

* Testing that all treatment effects are jointly zero.
test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/


quietly scalar coeff1`var' = round(coeff`var'[1,1],.01)
quietly scalar coeff2`var' = round(coeff`var'[1,2],.01)
quietly scalar coeff3`var' = round(coeff`var'[1,3],.01)

quietly scalar F`var' = round(r(F),.01)
quietly scalar pvalue`var' = round(r(p),.0001)

if pvalue`var' <= 0.01 quietly scalar `var'_stars = 1

if pvalue`var' <= 0.05 & pvalue`var' > 0.01 quietly scalar `var'_stars = 2

if pvalue`var' <= 0.1  & pvalue`var' > 0.05 quietly scalar `var'_stars = 3

if pvalue`var' > 0.1  quietly scalar `var'_stars = 0

quietly matrix RegF= nullmat(RegF) \ [F`var', pvalue`var']

quietly matrix Table2_STARS = nullmat(Table2_STARS) \ [0, 0, 0, 0, `var'_stars, 0]

}

* Columns and rows names

quietly matrix rownames RegF = `BS_descriptive'

quietly matrix colnames RegF = Fvalue Pvalue  

matrix list RegF 

* Number of observations
sum treat1_BR if round_fup==0 & treat1_BR==1
quietly matrix N= nullmat(N) \ [r(N)]
sum treat2_BR_TPIN if round_fup==0 & treat2_BR_TPIN==1
quietly matrix N= N, [r(N)]
sum treat3_BR_Bank if round_fup==0 & treat3_BR_Bank==1
quietly matrix N= N, [r(N)]
sum control if round_fup==0 & control==1
quietly matrix N= N, [r(N)]
sum control if round_fup==0
quietly matrix N= N, [r(N)], [r(N)]

matrix list N

* Matrix
matrix Table2=Table2_treat1_BR, Table2_treat2_BR_TPIN, Table2_treat3_BR_Bank, Table2_Control,  RegF 

xml_tab Table2 using "$analysis\Table2.xml", format(S2100, N2301, N2301, N2301, N2301, N2301, N2302) sheet(Table 2) star(* 0.1 ** 0.05 *** 0.01) replace

* Joint Orthogonality Test (JOT)
/*
Treat = b0 + b1*X1 + b2*X2 + b3*X3 + ... +bk*Xk +u
We test the joint hypothesis b1=b2=b3=...=bk=0
with an F-test, running a linear regression */

reg treat1_BR `BS_descriptive' if round_fup==0 & (treat1_BR==1 | control==1)
quietly scalar Ftreat1 = round(e(F),.01)
reg treat2_BR_TPIN `BS_descriptive' if round_fup==0 & (treat2_BR_TPIN==1 | control==1)
quietly scalar Ftreat2 = round(e(F),.01)
reg treat3_BR_Bank `BS_descriptive' if round_fup==0 & (treat3_BR_Bank==1 | control==1)
quietly scalar Ftreat3 = round(e(F),.01)
matrix JOT= Ftreat1, Ftreat2, Ftreat3

matrix list JOT


*** Table 3

* TAKE-UP ANALYSIS
*** Registration take-up

global treatment treat1_BR treat2_BR_TPIN treat3_BR_Bank
global int_treat_fem int_female_BR int_female_BR_TPIN int_female_BR_Bank
global int_treat_city int_city_BR int_city_BR_TPIN int_city_BR_Bank

* BRC take-up 
eststo: reg took_br $treatment strata_* if round_fup==0, r
mat b=e(b)
test treat1_BR=treat2_BR_TPIN
scalar pvaluetreat1= round(r(p),.001)
test treat1_BR=treat3_BR_Bank 
scalar pvaluetreat2= round(r(p),.001)

mat BRC_take_up= [b[1,1]*100\b[1,2]*100\b[1,3]*100\pvaluetreat1\pvaluetreat2\ . \.\.\.\.\.]


* BRC take-up by gender
eststo clear
eststo: reg took_br $treatment $int_treat_fem female strata_*  if round_fup==0, r
mat b=e(b)
test treat1_BR=treat2_BR_TPIN /****treat1=treat2 for male***/
scalar pvaluetreat3= round(r(p),.001)
test treat1_BR=treat3_BR_Bank /****treat1=treat3 for male***/
scalar pvaluetreat4= round(r(p),.001)
test treat1_BR+int_female_BR=treat2_BR_TPIN+int_female_BR_TPIN /****treat1=treat2 for female***/
scalar pvaluetreat5= round(r(p),.001)
test treat1_BR+int_female_BR=treat3_BR_Bank+int_female_BR_Bank /****treat1=treat3 for female***/
scalar pvaluetreat6= round(r(p),.001)
test treat1=treat1_BR+int_female_BR              /****female=male for treat 1***/
scalar pvaluegender1= round(r(p),.001)
test treat2=treat2_BR_TPIN+int_female_BR_TPIN    /****female=male for treat 2***/
scalar pvaluegender2= round(r(p),.001)
test treat3=treat3_BR_Bank+int_female_BR_Bank    /****female=male for treat 3***/
scalar pvaluegender3= round(r(p),.001)

mat BRC_take_up_male= [b[1,1]*100\b[1,2]*100\b[1,3]*100\pvaluetreat3\pvaluetreat4\ pvaluegender1 \pvaluegender2\pvaluegender3\.\.\.]

mat BRC_take_up_female= [b[1,1]*100+b[1,4]*100\b[1,2]*100+b[1,5]*100\b[1,3]*100+b[1,6]*100\pvaluetreat5\pvaluetreat6\ pvaluegender1 \pvaluegender2\pvaluegender3\.\.\.]

* BRC take-up by city
eststo clear
eststo: reg took_br $treatment $int_treat_city lilongwe strata_*  if round_fup==0, r
mat b=e(b)
test treat1_BR=treat2_BR_TPIN /****treat1=treat2 for blantyre***/
scalar pvaluetreat7= round(r(p),.001)
test treat1_BR=treat3_BR_Bank /****treat1=treat3 for blantyre***/
scalar pvaluetreat8= round(r(p),.001)
test treat1_BR+int_city_BR=treat2_BR_TPIN+int_city_BR_TPIN /****treat1=treat2 for lilongwe***/
scalar pvaluetreat9= round(r(p),.001)
test treat1_BR+int_city_BR=treat3_BR_Bank+int_city_BR_Bank /****treat1=treat3 for lilongwe***/
scalar pvaluetreat10= round(r(p),.001)
test treat1=treat1_BR+int_city_BR              /****lilongwe=blantyre for treat 1***/
scalar pvaluecity1= round(r(p),.001)
test treat2=treat2_BR_TPIN+int_city_BR_TPIN    /****lilongwe=blantyre for treat 2***/
scalar pvaluecity2= round(r(p),.001)
test treat3=treat3_BR_Bank+int_city_BR_Bank    /****lilongwe=blantyre for treat 3***/
scalar pvaluecity3= round(r(p),.001)

mat BRC_take_up_blantyre= [b[1,1]*100\b[1,2]*100\b[1,3]*100\pvaluetreat7\pvaluetreat8\.\.\.\ pvaluecity1 \pvaluecity2\pvaluecity3]

mat BRC_take_up_lilongwe= [b[1,1]*100+b[1,4]*100\b[1,2]*100+b[1,5]*100\b[1,3]*100+b[1,6]*100\pvaluetreat9\pvaluetreat10\.\.\.\ pvaluecity1 \pvaluecity2\pvaluecity3]


* TPIN take-up 
eststo clear
destring brc_tpin, replace 
reg brc_tpin $treatment $controls if round_fup==0, r
mat b=e(b)

mat TPIN_take_up= [. \b[1,2]*100\.\.\.\.\.\.\.\.\.]


* TPIN take-up by gender
reg brc_tpin $treatment $int_treat_fem female strata_* if round_fup==0, r
mat b=e(b)
test treat2=treat2_BR_TPIN+int_female_BR_TPIN
scalar pvalueTPINgender= round(r(p),.001)

mat TPIN_take_up_male= [. \b[1,2]*100\.\.\.\.\pvalueTPINgender\.\.\.\.]
mat TPIN_take_up_female= [. \b[1,2]*100+b[1,5]*100\.\.\.\.\pvalueTPINgender\.\.\.\.]

* opened BBA take-up
reg BBA_NBS_opened $treatment $controls if round_fup==0, r
mat b=e(b)
mat BBA_take_up= [. \.\b[1,3]*100\.\.\.\.\.\.\.\.]

* opened BBA take-up by gender
reg BBA_NBS_opened $treatment $int_treat_fem female strata_* if round_fup==0, r
mat b=e(b)
test treat3=treat3+int_female_BR_Bank
scalar pvalueBBAgender= round(r(p),.001)

mat BBA_take_up_male= [.\. \b[1,3]*100\.\.\.\.\pvalueBBAgender\.\.\.]
mat BBA_take_up_female= [. \.\b[1,3]*100+b[1,6]*100\.\.\.\.\pvalueBBAgender\.\.\.]


mat Table3=BRC_take_up, BRC_take_up_male, BRC_take_up_female, BRC_take_up_lilongwe, BRC_take_up_blantyre, TPIN_take_up , TPIN_take_up_male, TPIN_take_up_female, BBA_take_up, BBA_take_up_male, BBA_take_up_female

* Columns and rows names

quietly matrix colnames Table3 = BRC_FullSample	BRC_Male	BRC_Female	BRC_Lilongwe	BRC_Blantyre	TPIN_FullSample	TPIN_Male	TPIN_Female BBA_FullSample	BBA_Male	BBA_Female

quietly matrix rownames Table3 = BRC BRC_TPIN BRC_IS_BBA p-value_treat1and2 p-value_treat1and3 p-value_gendertreat1 p-value_gendertreat2 p-value_gendertreat3 p-value_citytreat1 p-value_citytreat2 p-value_citytreat3


mat list Table3

xml_tab Table3 using "$analysis\Table3.xml", sheet(Table 3) replace


*************************** REGRESSIONS *****************************

* areg command needs absorb: a group var
gen groupstrata=0
forvalues s=1/46 {
quietly	replace groupstrata=`s' if strata_`s'==1
	}
tab groupstrata

* Tables 4-10

*** Table 4: hypothesis A.1 - Impacts on Formalization (BRC, TPIN, City council)
eststo clear


* Estimation using all follow-up rounds

* z-score
		xi: areg avg_z_hyp_A_1_FU  treat1_BR treat2_BR_TPIN treat3_BR_Bank avg_z_hyp_A_1_BS  missBSavg_z_hyp_A_1 FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0 , a(groupstrata) cluster(id) robust
		eststo
		
		*q-values
		preserve
		parmest, norestore
		qqvalue p, method(simes) qvalue(qvalz_hyp_A_1)
		rename p p_z_hyp_A_1
		mkmat estimate stderr p_z_hyp_A_1 qvalz_hyp_A_1
		matrix TEMP1 =estimate, stderr, p_z_hyp_A_1, qvalz_hyp_A_1
		matrix list TEMP1
		matrix TEMP2= TEMP1[1..3, 1..4]'
		matrix list TEMP2
		matrix TABLE4Q = TEMP2[1..4, 1]
		matrix list TABLE4Q
		matrix TABLE4Q = TABLE4Q\TEMP2[1..4, 2]
		matrix TABLE4Q = TABLE4Q\TEMP2[1..4, 3]
		matrix list TABLE4Q 
		matrix colnames TABLE4Q = avg_z_hyp_z_hyp_A_1_FU
		mat drop estimate stderr p_z_hyp_A_1 qvalz_hyp_A_1 TEMP1 TEMP2
	    restore
		
		* Testing that all treatments are jointly equal in treatment effect. 
		test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
		estadd scalar pvalue1=r(p)
	
		test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
		estadd scalar pvalue2=r(p)
		
		test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
		estadd scalar pvalue3=r(p)
		
		* Testing that all treatment effects are jointly zero.
		test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
		estadd scalar pvalue4=r(p)
		
		* Control group mean
		sum avg_z_hyp_A_1_FU  if treatment==4  & F_no_attrition==1 & round_fup!=0
		estadd scalar mean1=r(mean)

* Each outcome separetly

foreach var of varlist has_BRC has_TPIN has_city_council  {	
			* All Follow-up rounds
			
			xi: areg F_`var'  treat1_BR treat2_BR_TPIN treat3_BR_Bank `var' missBS`var' FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0 , a(groupstrata) cluster(id) robust
			eststo

			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qval`var')
			rename p p_`var'
			mkmat estimate stderr p_`var' qval`var'
			matrix TEMP1 =estimate, stderr, p_`var', qval`var'
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_`var' = TEMP2[1..4, 1]
			matrix list M_`var'
			matrix M_`var' = M_`var'\TEMP2[1..4, 2]
			matrix M_`var' = M_`var'\TEMP2[1..4, 3]
			matrix list M_`var' 
			matrix colnames M_`var' = `var'
			matrix TABLE4Q = TABLE4Q, M_`var' 
			mat drop estimate stderr p_`var' qval`var' TEMP1 TEMP2 M_`var'
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
		
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)
			
			* Control group mean
			sum F_`var'  if treatment==4 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)
			}
			
* Testing equality of treatment effects over time (i.e. that the effect is the same in round 1, round 2, round 3, and round 4).
  /* Y(i,t) = b0 + b1*FU1*BRC(i) + b2*FU2*BRC(i)+ b3*FU3*BRC(i) + b4*FU4*BRC(i) + 
				  c1*FU1*[BRC+TPIN](i) + c2*FU2* [BRC+TPIN](i)+ c3*FU3*[BRC+TPIN](i) + c4*FU4*[BRC+TPIN](i) + 
				  d1*FU1*[BRC+BBA](i) + d2*FU2* [BRC+BBA](i)+ d3*FU3*[BRC+BBA](i) + d4*FU4*[BRC+BBA](i) +
				  f2*FU2 + f3*FU3 + f4*FU4 + g*Strata dummies + h*BaselineY(i,t) + j * missingBSdatadummy + e(i,t) */

			# d ;
				 xi: areg avg_z_hyp_A_1_FU FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 avg_z_hyp_A_1_BS  missBSavg_z_hyp_A_1 if F_no_attrition==1 & round_fup!=0 , ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)
			
			* Each outcome separetly
			foreach var of varlist has_BRC has_TPIN has_city_council  {
						
			# d ;
				 xi: areg F_`var' FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 `var' missBS`var' if F_no_attrition==1 & round_fup!=0 , ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)			
			}


* We save estimation results			
esttab,  stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) se star(* 0.10 ** 0.05 *** 0.01)
esttab using "$analysis\Table4.csv", stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) replace

xml_tab TABLE4Q  using "$analysis\qvalues\Table4q-values.xml", format(S2100, N2303, N2303, N2303, N2303, N2303 ) sheet("Table4") replace

eststo clear



*** Table 5: Gender Heterogeneity in Impacts on Formalization
		
****interaction with gender

* Estimation using all follow-up rounds

* z-score

	xi: areg avg_z_hyp_A_1_FU  treat1_BR treat2_BR_TPIN treat3_BR_Bank int_female_BR int_female_BR_TPIN int_female_BR_Bank  female avg_z_hyp_A_1_BS  missBSavg_z_hyp_A_1 FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
	eststo

    *q-values
	 preserve
	 parmest, norestore
	 qqvalue p, method(simes) qvalue(qvalz_hyp_A_1g)
	 rename p p_z_hyp_A_1g
	 mkmat estimate stderr p_z_hyp_A_1g qvalz_hyp_A_1g
	 matrix TEMP1 =estimate, stderr, p_z_hyp_A_1g, qvalz_hyp_A_1g
	 matrix list TEMP1
	 matrix TEMP2= TEMP1[1..6, 1..4]'
	 matrix list TEMP2
	 matrix TABLE5Q = TEMP2[1..4, 1]
	 matrix list TABLE5Q
	 matrix TABLE5Q = TABLE5Q\TEMP2[1..4, 2]
	 matrix TABLE5Q = TABLE5Q\TEMP2[1..4, 3]
	 matrix TABLE5Q = TABLE5Q\TEMP2[1..4, 4]	 
	 matrix TABLE5Q = TABLE5Q\TEMP2[1..4, 5]
	 matrix TABLE5Q = TABLE5Q\TEMP2[1..4, 6]
	 matrix list TABLE5Q 
	 matrix colnames TABLE5Q = avg_z_hyp_z_hyp_A_1_FU
	 mat drop estimate stderr p_z_hyp_A_1g qvalz_hyp_A_1g TEMP1 TEMP2
	 restore
	 
	* Testing that all treatments are jointly equal in treatment effect. 
	test treat1_BR=treat2_BR_TPIN  /*treat1=treat2 for male */
	estadd scalar pvalue1=r(p)
	
	test treat1_BR=treat3_BR_Bank  /*treat1=treat3 for male */
	estadd scalar pvalue2=r(p)
	
	test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3 for male */
	estadd scalar pvalue3=r(p)
	
	test treat1_BR + int_female_BR =treat2_BR_TPIN + int_female_BR_TPIN  /*treat1=treat2 for female*/
	estadd scalar pvalue4=r(p)
	
	test treat1_BR + int_female_BR =treat3_BR_Bank + int_female_BR_Bank  /*treat1=treat3 for female*/
	estadd scalar pvalue5=r(p)
	
	test treat2_BR_TPIN + int_female_BR_TPIN =treat3_BR_Bank + int_female_BR_Bank  /*treat2=treat3 for female*/
	estadd scalar pvalue6=r(p)
	
	
	* Testing that all treatment effects are jointly zero.
	test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0 for male*/
	estadd scalar pvalue7=r(p)
	test treat1_BR + int_female_BR =treat2_BR_TPIN + int_female_BR_TPIN =treat3_BR_Bank + int_female_BR_Bank =0   /*treat1=treat2=treat3=0 for female*/
	estadd scalar pvalue8=r(p)

    * Control group mean
	sum avg_z_hyp_A_1_FU  if treatment==4 & F_no_attrition==1 & round_fup!=0
	estadd scalar mean1=r(mean)
	sum avg_z_hyp_A_1_FU if treatment==4 & female==0 & F_no_attrition==1 & round_fup!=0
	estadd scalar mean2=r(mean)
	sum avg_z_hyp_A_1_FU if treatment==4 & female==1 & F_no_attrition==1 & round_fup!=0
	estadd scalar mean3=r(mean)	


* Each outcome separetly

			foreach var of varlist has_BRC has_TPIN has_city_council {
		
			* All Follow-up rounds

			xi: areg F_`var'  treat1_BR treat2_BR_TPIN treat3_BR_Bank int_female_BR int_female_BR_TPIN int_female_BR_Bank  female  `var' missBS`var'  FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
			eststo
			
			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qval`var'g)
			rename p p_`var'g
			mkmat estimate stderr p_`var'g qval`var'g
			matrix TEMP1 =estimate, stderr, p_`var'g, qval`var'g
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..6, 1..4]'
			matrix list TEMP2
			matrix Mg_`var' = TEMP2[1..4, 1]
			matrix list Mg_`var'
			matrix Mg_`var' = Mg_`var'\TEMP2[1..4, 2]
			matrix Mg_`var' = Mg_`var'\TEMP2[1..4, 3]
			matrix Mg_`var' = Mg_`var'\TEMP2[1..4, 4]
			matrix Mg_`var' = Mg_`var'\TEMP2[1..4, 5]
			matrix Mg_`var' = Mg_`var'\TEMP2[1..4, 6]
			matrix list Mg_`var' 
			matrix colnames Mg_`var' = `var'
			matrix TABLE5Q = TABLE5Q, Mg_`var' 
			mat drop estimate stderr p_`var'g qval`var'g TEMP1 TEMP2 Mg_`var'
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2 for male ...*/
			estadd scalar pvalue1=r(p)
			
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3 for male ...*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3 for male ...*/
			estadd scalar pvalue3=r(p)
			
			test treat1_BR + int_female_BR =treat2_BR_TPIN + int_female_BR_TPIN  /*treat1=treat2 for female ...*/
			estadd scalar pvalue4=r(p)
			
			test treat1_BR + int_female_BR =treat3_BR_Bank + int_female_BR_Bank  /*treat1=treat3 for female ...*/
			estadd scalar pvalue5=r(p)
			
			test treat2_BR_TPIN + int_female_BR_TPIN =treat3_BR_Bank + int_female_BR_Bank  /*treat2=treat3 for female ...*/
			estadd scalar pvalue6=r(p)
			
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0 for male ...*/
			estadd scalar pvalue7=r(p)
			test treat1_BR + int_female_BR =treat2_BR_TPIN + int_female_BR_TPIN =treat3_BR_Bank + int_female_BR_Bank =0   /*treat1=treat2=treat3=0 for female ...*/
			estadd scalar pvalue8=r(p)
	
			* Control group mean
			sum F_`var' if treatment==4 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)
			sum F_`var' if treatment==4 & female==0 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean2=r(mean)
			sum F_`var' if treatment==4 & female==1 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean3=r(mean)
	
			}

			
* We save estimation results
esttab,  stats(mean2 mean3 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 pvalue8 ) se star(* 0.10 ** 0.05 *** 0.01)
esttab using "$analysis\Table5.csv", stats(mean2 mean3 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 pvalue8 ) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) replace

xml_tab TABLE5Q  using "$analysis\qvalues\Table5q-values.xml", format(S2100, N2303, N2303, N2303, N2303, N2303 ) sheet("Table5") replace

eststo clear


*** Table 6: hypothesis A.2 - Impacts on Business Performance (profits and sales)

* Estimation using all follow-up rounds

* z-score
		xi: areg avg_z_hyp_A_2_FU  treat1_BR treat2_BR_TPIN treat3_BR_Bank avg_z_hyp_A_2_BS  missBSavg_z_hyp_A_2 FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
		eststo

		*q-values
		preserve
		parmest, norestore
		qqvalue p, method(simes) qvalue(qvalz_hyp_A_2)
		rename p p_z_hyp_A_2
		mkmat estimate stderr p_z_hyp_A_2 qvalz_hyp_A_2
		matrix TEMP1 =estimate, stderr, p_z_hyp_A_2, qvalz_hyp_A_2
		matrix list TEMP1
		matrix TEMP2= TEMP1[1..3, 1..4]'
		matrix list TEMP2
		matrix TABLE6Q = TEMP2[1..4, 1]
		matrix list TABLE6Q
		matrix TABLE6Q = TABLE6Q\TEMP2[1..4, 2]
		matrix TABLE6Q = TABLE6Q\TEMP2[1..4, 3]
		matrix list TABLE6Q 
		matrix colnames TABLE6Q = avg_z_hyp_z_hyp_A_2_FU
		mat drop estimate stderr p_z_hyp_A_2 qvalz_hyp_A_2 TEMP1 TEMP2
	    restore
		
		* Testing that all treatments are jointly equal in treatment effect. 
		test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
		estadd scalar pvalue1=r(p)
	
		test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
		estadd scalar pvalue2=r(p)
		
		test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
		estadd scalar pvalue3=r(p)
		
		* Testing that all treatment effects are jointly zero.
		test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
		estadd scalar pvalue4=r(p)
		
		* Control group mean
		sum avg_z_hyp_A_2_FU  if treatment==4  & F_no_attrition==1 & round_fup!=0
		estadd scalar mean1=r(mean)

* Each outcome separetly
foreach var of varlist avg_z_Revenue  avg_z_Profit usd_Revenue_lastmonth usd_Revenue_lastmonth99 usd_Profit_lastmonth usd_Profit_lastmonth99 {	
			* All Follow-up rounds
			
			xi: areg F_`var'  treat1_BR treat2_BR_TPIN treat3_BR_Bank `var' missBS`var' FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
			eststo
			
			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qval`var')
			rename p p_`var'
			mkmat estimate stderr p_`var' qval`var'
			matrix TEMP1 =estimate, stderr, p_`var', qval`var'
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_`var' = TEMP2[1..4, 1]
			matrix list M_`var'
			matrix M_`var' = M_`var'\TEMP2[1..4, 2]
			matrix M_`var' = M_`var'\TEMP2[1..4, 3]
			matrix list M_`var' 
			matrix colnames M_`var' = `var'
			matrix TABLE6Q = TABLE6Q, M_`var' 
			mat drop estimate stderr p_`var' qval`var' TEMP1 TEMP2 M_`var'
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
		
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)
			
			* Control group mean
			sum F_`var'  if treatment==4 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)
			}
			
* Testing equality of treatment effects over time (i.e. that the effect is the same in round 1, round 2, round 3, and round 4).
  /* Y(i,t) = b0 + b1*FU1*BRC(i) + b2*FU2*BRC(i)+ b3*FU3*BRC(i) + b4*FU4*BRC(i) + 
				  c1*FU1*[BRC+TPIN](i) + c2*FU2* [BRC+TPIN](i)+ c3*FU3*[BRC+TPIN](i) + c4*FU4*[BRC+TPIN](i) + 
				  d1*FU1*[BRC+BBA](i) + d2*FU2* [BRC+BBA](i)+ d3*FU3*[BRC+BBA](i) + d4*FU4*[BRC+BBA](i) +
				  f2*FU2 + f3*FU3 + f4*FU4 + g*Strata dummies + h*BaselineY(i,t) + j * missingBSdatadummy + e(i,t) */

			# d ;
				 xi: areg avg_z_hyp_A_2_FU FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 avg_z_hyp_A_2_BS  missBSavg_z_hyp_A_2 if F_no_attrition==1 & round_fup!=0 , ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)
			
			* Each outcome
			foreach var of varlist avg_z_Revenue  avg_z_Profit usd_Revenue_lastmonth usd_Revenue_lastmonth99 usd_Profit_lastmonth usd_Profit_lastmonth99  {
						
			# d ;
				 xi: areg F_`var' FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 `var' missBS`var' if F_no_attrition==1 & round_fup!=0 , ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)			
			}


* We save estimation results			
esttab,  stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) se star(* 0.10 ** 0.05 *** 0.01)
esttab using "$analysis\Table6.csv", stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) replace

xml_tab TABLE6Q  using "$analysis\qvalues\Table6q-values.xml", format(S2100, N2303, N2303, N2303, N2303, N2303, N2303, N2303 ) sheet("Table6") replace

eststo clear


* Table 7 Gender Heterogeneity in Impacts on Business Performance
		
****interaction with gender

* Estimation using all follow-up rounds

* z-score

	xi: areg avg_z_hyp_A_2_FU  treat1_BR treat2_BR_TPIN treat3_BR_Bank int_female_BR int_female_BR_TPIN int_female_BR_Bank  female avg_z_hyp_A_2_BS  missBSavg_z_hyp_A_2 FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
	eststo

    *q-values
	 preserve
	 parmest, norestore
	 qqvalue p, method(simes) qvalue(qvalz_hyp_A_2g)
	 rename p p_z_hyp_A_2g
	 mkmat estimate stderr p_z_hyp_A_2g qvalz_hyp_A_2g
	 matrix TEMP1 =estimate, stderr, p_z_hyp_A_2g, qvalz_hyp_A_2g
	 matrix list TEMP1
	 matrix TEMP2= TEMP1[1..6, 1..4]'
	 matrix list TEMP2
	 matrix TABLE7Q = TEMP2[1..4, 1]
	 matrix list TABLE7Q
	 matrix TABLE7Q = TABLE7Q\TEMP2[1..4, 2]
	 matrix TABLE7Q = TABLE7Q\TEMP2[1..4, 3]
	 matrix TABLE7Q = TABLE7Q\TEMP2[1..4, 4]	 
	 matrix TABLE7Q = TABLE7Q\TEMP2[1..4, 5]
	 matrix TABLE7Q = TABLE7Q\TEMP2[1..4, 6]
	 matrix list TABLE7Q 
	 matrix colnames TABLE7Q = avg_z_hyp_z_hyp_A_2_FU
	 mat drop estimate stderr p_z_hyp_A_2g qvalz_hyp_A_2g TEMP1 TEMP2
	 restore
		
	* Testing that all treatments are jointly equal in treatment effect. 
	test treat1_BR=treat2_BR_TPIN  /*treat1=treat2 for male */
	estadd scalar pvalue1=r(p)
	
	test treat1_BR=treat3_BR_Bank  /*treat1=treat3 for male */
	estadd scalar pvalue2=r(p)
	
	test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3 for male */
	estadd scalar pvalue3=r(p)
	
	test treat1_BR + int_female_BR =treat2_BR_TPIN + int_female_BR_TPIN  /*treat1=treat2 for female*/
	estadd scalar pvalue4=r(p)
	
	test treat1_BR + int_female_BR =treat3_BR_Bank + int_female_BR_Bank  /*treat1=treat3 for female*/
	estadd scalar pvalue5=r(p)
	
	test treat2_BR_TPIN + int_female_BR_TPIN =treat3_BR_Bank + int_female_BR_Bank  /*treat2=treat3 for female*/
	estadd scalar pvalue6=r(p)
	
	
	* Testing that all treatment effects are jointly zero.
	test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0 for male*/
	estadd scalar pvalue7=r(p)
	test treat1_BR + int_female_BR =treat2_BR_TPIN + int_female_BR_TPIN =treat3_BR_Bank + int_female_BR_Bank =0   /*treat1=treat2=treat3=0 for female*/
	estadd scalar pvalue8=r(p)

    * Control group mean
	sum avg_z_hyp_A_2_FU  if treatment==4 & F_no_attrition==1 & round_fup!=0
	estadd scalar mean1=r(mean)
	sum avg_z_hyp_A_2_FU if treatment==4 & female==0 & F_no_attrition==1 & round_fup!=0	
	estadd scalar mean2=r(mean)
	sum avg_z_hyp_A_2_FU if treatment==4 & female==1 & F_no_attrition==1 & round_fup!=0
	estadd scalar mean3=r(mean)	


* Each outcome separetly

			foreach var of varlist avg_z_Revenue  avg_z_Profit usd_Revenue_lastmonth usd_Revenue_lastmonth99 usd_Profit_lastmonth usd_Profit_lastmonth99 {
		
			* All Follow-up rounds

			xi: areg F_`var'  treat1_BR treat2_BR_TPIN treat3_BR_Bank int_female_BR int_female_BR_TPIN int_female_BR_Bank  female  `var' missBS`var'  FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
			eststo
			
			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qval`var'g)
			rename p p_`var'g
			mkmat estimate stderr p_`var'g qval`var'g
			matrix TEMP1 =estimate, stderr, p_`var'g, qval`var'g
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..6, 1..4]'
			matrix list TEMP2
			matrix Mg_`var' = TEMP2[1..4, 1]
			matrix list Mg_`var'
			matrix Mg_`var' = Mg_`var'\TEMP2[1..4, 2]
			matrix Mg_`var' = Mg_`var'\TEMP2[1..4, 3]
			matrix Mg_`var' = Mg_`var'\TEMP2[1..4, 4]
			matrix Mg_`var' = Mg_`var'\TEMP2[1..4, 5]
			matrix Mg_`var' = Mg_`var'\TEMP2[1..4, 6]
			matrix list Mg_`var' 
			matrix colnames Mg_`var' = `var'
			matrix TABLE7Q = TABLE7Q, Mg_`var' 
			mat drop estimate stderr p_`var'g qval`var'g TEMP1 TEMP2 Mg_`var'
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2 for male ...*/
			estadd scalar pvalue1=r(p)
			
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3 for male ...*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3 for male ...*/
			estadd scalar pvalue3=r(p)
			
			test treat1_BR + int_female_BR =treat2_BR_TPIN + int_female_BR_TPIN  /*treat1=treat2 for female ...*/
			estadd scalar pvalue4=r(p)
			
			test treat1_BR + int_female_BR =treat3_BR_Bank + int_female_BR_Bank  /*treat1=treat3 for female ...*/
			estadd scalar pvalue5=r(p)
			
			test treat2_BR_TPIN + int_female_BR_TPIN =treat3_BR_Bank + int_female_BR_Bank  /*treat2=treat3 for female ...*/
			estadd scalar pvalue6=r(p)
			
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0 for male ...*/
			estadd scalar pvalue7=r(p)
			test treat1_BR + int_female_BR =treat2_BR_TPIN + int_female_BR_TPIN =treat3_BR_Bank + int_female_BR_Bank =0   /*treat1=treat2=treat3=0 for female ...*/
			estadd scalar pvalue8=r(p)
	
			* Control group mean
			sum F_`var' if treatment==4 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)
			sum F_`var' if treatment==4 & female==0 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean2=r(mean)
			sum F_`var' if treatment==4 & female==1 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean3=r(mean)
	
			}

			
* We save estimation results
esttab,  stats(mean2 mean3 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 pvalue8 ) se star(* 0.10 ** 0.05 *** 0.01)
esttab using "$analysis\Table7.csv", stats(mean2 mean3 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 pvalue8 ) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) replace

xml_tab TABLE7Q  using "$analysis\qvalues\Table7q-values.xml", format(S2100, N2303, N2303, N2303, N2303, N2303, N2303, N2303 ) sheet("Table7") replace

eststo clear


* Table 8: Channels of impacts on firms (C2: impacts on inspections and harassment, FS: impacts on financial services)

* Estimation using all follow-up rounds

* z-score
foreach hyp in C2 FS  {
		xi: areg avg_z_hyp_`hyp'_FU  treat1_BR treat2_BR_TPIN treat3_BR_Bank avg_z_hyp_`hyp'_BS  missBSavg_z_hyp_`hyp' FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
		eststo

		*q-values
		preserve
		parmest, norestore
		qqvalue p, method(simes) qvalue(qvalz_hyp_`hyp')
		rename p p_z_hyp_`hyp'
		mkmat estimate stderr p_z_hyp_`hyp' qvalz_hyp_`hyp'
		matrix TEMP1 =estimate, stderr, p_z_hyp_`hyp', qvalz_hyp_`hyp'
		matrix list TEMP1
		matrix TEMP2= TEMP1[1..3, 1..4]'
		matrix list TEMP2
		matrix TABLE8`hyp'Q = TEMP2[1..4, 1]
		matrix list TABLE8`hyp'Q
		matrix TABLE8`hyp'Q = TABLE8`hyp'Q\TEMP2[1..4, 2]
		matrix TABLE8`hyp'Q = TABLE8`hyp'Q\TEMP2[1..4, 3]
		matrix list TABLE8`hyp'Q 
		matrix colnames TABLE8`hyp'Q = avg_z_hyp_z_hyp_`hyp'_FU
		mat drop estimate stderr p_z_hyp_`hyp' qvalz_hyp_`hyp' TEMP1 TEMP2
	    restore
		
		
		* Testing that all treatments are jointly equal in treatment effect. 
		test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
		estadd scalar pvalue1=r(p)
	
		test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
		estadd scalar pvalue2=r(p)
		
		test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
		estadd scalar pvalue3=r(p)
		
		* Testing that all treatment effects are jointly zero.
		test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
		estadd scalar pvalue4=r(p)
		
		* Control group mean
		sum avg_z_hyp_`hyp'_FU  if treatment==4 & F_no_attrition==1 & round_fup!=0
		estadd scalar mean1=r(mean)
}
		matrix TABLE8Q=nullmat(TABLE8Q), TABLE8C2Q,TABLE8FSQ

* Each outcome separetly

foreach var of varlist banksonly_bus_account chamber export_license tender changes_location {	
			* All Follow-up rounds
			
			xi: areg F_`var'  treat1_BR treat2_BR_TPIN treat3_BR_Bank `var' missBS`var' FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
			eststo
			
			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qval`var')
			rename p p_`var'
			mkmat estimate stderr p_`var' qval`var'
			matrix TEMP1 =estimate, stderr, p_`var', qval`var'
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_`var' = TEMP2[1..4, 1]
			matrix list M_`var'
			matrix M_`var' = M_`var'\TEMP2[1..4, 2]
			matrix M_`var' = M_`var'\TEMP2[1..4, 3]
			matrix list M_`var' 
			matrix colnames M_`var' = `var'
			matrix TABLE8Q = TABLE8Q, M_`var' 
			mat drop estimate stderr p_`var' qval`var' TEMP1 TEMP2 M_`var'
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
		
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)
			
			* Control group mean
			sum F_`var'  if treatment==4 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)
			}
			
* Testing equality of treatment effects over time (i.e. that the effect is the same in round 1, round 2, round 3, and round 4).
  /* Y(i,t) = b0 + b1*FU1*BRC(i) + b2*FU2*BRC(i)+ b3*FU3*BRC(i) + b4*FU4*BRC(i) + 
				  c1*FU1*[BRC+TPIN](i) + c2*FU2* [BRC+TPIN](i)+ c3*FU3*[BRC+TPIN](i) + c4*FU4*[BRC+TPIN](i) + 
				  d1*FU1*[BRC+BBA](i) + d2*FU2* [BRC+BBA](i)+ d3*FU3*[BRC+BBA](i) + d4*FU4*[BRC+BBA](i) +
				  f2*FU2 + f3*FU3 + f4*FU4 + g*Strata dummies + h*BaselineY(i,t) + j * missingBSdatadummy + e(i,t) */

foreach hyp in C2 FS  {
			# d ;
				 xi: areg avg_z_hyp_`hyp'_FU FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 avg_z_hyp_`hyp'_BS  missBSavg_z_hyp_`hyp' if F_no_attrition==1 & round_fup!=0, ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)
			}
			
			* Each outcome
			foreach var of varlist banksonly_bus_account chamber export_license tender changes_location  {
						
			# d ;
				 xi: areg F_`var' FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 `var' missBS`var' if F_no_attrition==1 & round_fup!=0, ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)			
			}


* We save estimation results			
esttab,  stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) se star(* 0.10 ** 0.05 *** 0.01)
esttab using "$analysis\Table8.csv", stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) replace

xml_tab TABLE8Q  using "$analysis\qvalues\Table8q-values.xml", format(S2100, N2303, N2303, N2303, N2303, N2303, N2303, N2303 ) sheet("Table8") replace

eststo clear


*** Table 9: Impacts on Use of Finance (UF)

* Estimation using all follow-up rounds

* z-score
		xi: areg avg_z_hyp_UF_FU  treat1_BR treat2_BR_TPIN treat3_BR_Bank avg_z_hyp_UF_BS  missBSavg_z_hyp_UF FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
		eststo
		
		*q-values
		preserve
		parmest, norestore
		qqvalue p, method(simes) qvalue(qvalz_hyp_UF)
		rename p p_z_hyp_UF
		mkmat estimate stderr p_z_hyp_UF qvalz_hyp_UF
		matrix TEMP1 =estimate, stderr, p_z_hyp_UF, qvalz_hyp_UF
		matrix list TEMP1
		matrix TEMP2= TEMP1[1..3, 1..4]'
		matrix list TEMP2
		matrix TABLE9Q = TEMP2[1..4, 1]
		matrix list TABLE9Q
		matrix TABLE9Q = TABLE9Q\TEMP2[1..4, 2]
		matrix TABLE9Q = TABLE9Q\TEMP2[1..4, 3]
		matrix list TABLE9Q 
		matrix colnames TABLE9Q = avg_z_hyp_z_hyp_UF_FU
		mat drop estimate stderr p_z_hyp_UF qvalz_hyp_UF TEMP1 TEMP2
	    restore
		
		* Testing that all treatments are jointly equal in treatment effect. 
		test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
		estadd scalar pvalue1=r(p)
	
		test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
		estadd scalar pvalue2=r(p)
		
		test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
		estadd scalar pvalue3=r(p)
		
		* Testing that all treatment effects are jointly zero.
		test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
		estadd scalar pvalue4=r(p)
		
		* Control group mean
		sum avg_z_hyp_UF_FU  if treatment==4  & F_no_attrition==1 & round_fup!=0
		estadd scalar mean1=r(mean)

* Each outcome separetly

foreach var of varlist usd_loan_can_raise usd_amount_recentloan  insurance  usd_saved_amount_bank highrelative_savings no_mix_bus_hh financial_records  {	
			* All Follow-up rounds
			
			xi: areg F_`var'  treat1_BR treat2_BR_TPIN treat3_BR_Bank `var' missBS`var' FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
			eststo
			
			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qval`var')
			rename p p_`var'
			mkmat estimate stderr p_`var' qval`var'
			matrix TEMP1 =estimate, stderr, p_`var', qval`var'
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_`var' = TEMP2[1..4, 1]
			matrix list M_`var'
			matrix M_`var' = M_`var'\TEMP2[1..4, 2]
			matrix M_`var' = M_`var'\TEMP2[1..4, 3]
			matrix list M_`var' 
			matrix colnames M_`var' = `var'
			matrix TABLE9Q = TABLE9Q, M_`var' 
			mat drop estimate stderr p_`var' qval`var' TEMP1 TEMP2 M_`var'
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
		
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)
			
			* Control group mean
			sum F_`var'  if treatment==4 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)
			}
			
			* Bank contacted the firm
			* Follow-up rounds 3 and 4
			
			xi: areg F_contact_bank   treat1_BR treat2_BR_TPIN treat3_BR_Bank contact_bank  missBScontact_bank  FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0 & (round_fup==3 | round_fup==4), a(groupstrata) cluster(id) robust
			eststo

			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qvalcontact_bank)
			rename p p_contact_bank
			mkmat estimate stderr p_contact_bank qvalcontact_bank
			matrix TEMP1 =estimate, stderr, p_contact_bank, qvalcontact_bank
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_contact_bank = TEMP2[1..4, 1]
			matrix list M_contact_bank
			matrix M_contact_bank = M_contact_bank\TEMP2[1..4, 2]
			matrix M_contact_bank = M_contact_bank\TEMP2[1..4, 3]
			matrix list M_contact_bank 
			matrix colnames M_contact_bank = contact_bank
			matrix TABLE9Q = TABLE9Q, M_contact_bank 
			mat drop estimate stderr p_contact_bank qvalcontact_bank TEMP1 TEMP2 M_contact_bank
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
		
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)
			
			* Control group mean
			sum F_contact_bank   if treatment==4 & F_no_attrition==1 & round_fup!=0 & (round_fup==3 | round_fup==4)
			estadd scalar mean1=r(mean)			
			
			
* Testing equality of treatment effects over time (i.e. that the effect is the same in round 1, round 2, round 3, and round 4).
  /* Y(i,t) = b0 + b1*FU1*BRC(i) + b2*FU2*BRC(i)+ b3*FU3*BRC(i) + b4*FU4*BRC(i) + 
				  c1*FU1*[BRC+TPIN](i) + c2*FU2* [BRC+TPIN](i)+ c3*FU3*[BRC+TPIN](i) + c4*FU4*[BRC+TPIN](i) + 
				  d1*FU1*[BRC+BBA](i) + d2*FU2* [BRC+BBA](i)+ d3*FU3*[BRC+BBA](i) + d4*FU4*[BRC+BBA](i) +
				  f2*FU2 + f3*FU3 + f4*FU4 + g*Strata dummies + h*BaselineY(i,t) + j * missingBSdatadummy + e(i,t) */

			# d ;
				 xi: areg avg_z_hyp_UF_FU FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 avg_z_hyp_UF_BS  missBSavg_z_hyp_UF if F_no_attrition==1 & round_fup!=0 , ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)
			
			* Each outcome
			foreach var of varlist usd_loan_can_raise usd_amount_recentloan  insurance  usd_saved_amount_bank highrelative_savings no_mix_bus_hh financial_records    {
						
			# d ;
				 xi: areg F_`var' FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 `var' missBS`var' if F_no_attrition==1 & round_fup!=0, ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)			
			}

			* Bank contacted the firm
			# d ;
				 xi: areg F_contact_bank FU3treat1_BR  FU4treat1_BR 
									 FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU3 contact_bank missBScontact_bank if F_no_attrition==1 & round_fup!=0 & (round_fup==3 | round_fup==4), ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)	
			



* We save estimation results			
esttab,  stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) se star(* 0.10 ** 0.05 *** 0.01)
esttab using "$analysis\Table9.csv", stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) replace

xml_tab TABLE9Q  using "$analysis\qvalues\Table9q-values.xml", format(S2100, N2303, N2303, N2303, N2303, N2303, N2303, N2303, N2303, N2303 ) sheet("Table9") replace

eststo clear


*** Table 10: Impacts on Taxes and Trust in the State

foreach var of varlist usd_taxescosts receipt z_trustgov {	
			* All Follow-up rounds
			
			xi: areg F_`var'  treat1_BR treat2_BR_TPIN treat3_BR_Bank `var' missBS`var' FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
			eststo
			
			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qval`var')
			rename p p_`var'
			mkmat estimate stderr p_`var' qval`var'
			matrix TEMP1 =estimate, stderr, p_`var', qval`var'
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_`var' = TEMP2[1..4, 1]
			matrix list M_`var'
			matrix M_`var' = M_`var'\TEMP2[1..4, 2]
			matrix M_`var' = M_`var'\TEMP2[1..4, 3]
			matrix list M_`var' 
			matrix colnames M_`var' = `var'
			matrix TABLE10Q = nullmat(TABLE10Q), M_`var' 
			mat drop estimate stderr p_`var' qval`var' TEMP1 TEMP2 M_`var'
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
		
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)
			
			* Control group mean
			sum F_`var'  if treatment==4 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)
			
* Testing equality of treatment effects over time (i.e. that the effect is the same in round 1, round 2, round 3, and round 4).
  /* Y(i,t) = b0 + b1*FU1*BRC(i) + b2*FU2*BRC(i)+ b3*FU3*BRC(i) + b4*FU4*BRC(i) + 
				  c1*FU1*[BRC+TPIN](i) + c2*FU2* [BRC+TPIN](i)+ c3*FU3*[BRC+TPIN](i) + c4*FU4*[BRC+TPIN](i) + 
				  d1*FU1*[BRC+BBA](i) + d2*FU2* [BRC+BBA](i)+ d3*FU3*[BRC+BBA](i) + d4*FU4*[BRC+BBA](i) +
				  f2*FU2 + f3*FU3 + f4*FU4 + g*Strata dummies + h*BaselineY(i,t) + j * missingBSdatadummy + e(i,t) */
					
			# d ;
				 xi: areg F_`var' FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 `var' missBS`var' if F_no_attrition==1 & round_fup!=0 , ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)			
			}


* Trust in institutions dealing with private sector(no baseline info)

 		* All Follow-up rounds
			
			xi: areg F_z_trustprivate  treat1_BR treat2_BR_TPIN treat3_BR_Bank FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
			eststo
			
			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qvalz_trustprivate)
			rename p p_z_trustprivate
			mkmat estimate stderr p_z_trustprivate qvalz_trustprivate
			matrix TEMP1 =estimate, stderr, p_z_trustprivate, qvalz_trustprivate
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_z_trustprivate = TEMP2[1..4, 1]
			matrix list M_z_trustprivate
			matrix M_z_trustprivate = M_z_trustprivate\TEMP2[1..4, 2]
			matrix M_z_trustprivate = M_z_trustprivate\TEMP2[1..4, 3]
			matrix list M_z_trustprivate
			matrix colnames M_z_trustprivate = z_trustprivate
			matrix TABLE10Q = nullmat(TABLE10Q), M_z_trustprivate 
			mat drop estimate stderr p_z_trustprivate qvalz_trustprivate TEMP1 TEMP2 M_z_trustprivate
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
		
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)
			
			* Control group mean
			sum F_z_trustprivate   if treatment==4 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)
			
* Testing equality of treatment effects over time (i.e. that the effect is the same in round 1, round 2, round 3, and round 4).
  /* Y(i,t) = b0 + b1*FU1*BRC(i) + b2*FU2*BRC(i)+ b3*FU3*BRC(i) + b4*FU4*BRC(i) + 
				  c1*FU1*[BRC+TPIN](i) + c2*FU2* [BRC+TPIN](i)+ c3*FU3*[BRC+TPIN](i) + c4*FU4*[BRC+TPIN](i) + 
				  d1*FU1*[BRC+BBA](i) + d2*FU2* [BRC+BBA](i)+ d3*FU3*[BRC+BBA](i) + d4*FU4*[BRC+BBA](i) +
				  f2*FU2 + f3*FU3 + f4*FU4 + g*Strata dummies + e(i,t) */
					
			# d ;
				 xi: areg F_z_trustprivate FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0 , ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)			
			
			
* We save estimation results			
esttab,  stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) se star(* 0.10 ** 0.05 *** 0.01)
esttab using "$analysis\Table10.csv", stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) replace

xml_tab TABLE10Q  using "$analysis\qvalues\Table10q-values.xml", format(S2100, N2303, N2303, N2303, N2303, N2303, N2303) sheet("Table10") replace

eststo clear


* Appendix

* Table A1

* Baseline variables
#d ;
local BS_descriptive_TableA1 
Manufacturing Retail Services  Total_workers2 Business_owner firm_age lilongwe owner_started own_space innov   /* Firm Characteristics */
advert Business_plan budget financial_records receipt electricity_access num_customers_month netw_anyline Num_competitors
owner_age Married hh_decision_index  Selfmainprovider Literate primary_completed Seconday_completed Higher_education /* Individual Characteristics */
high_capture Financial_knowledge mother_enterpreneur mother_wage_employt father_enterpreneur father_wage_employt spouse_enterpreneur spouse_wage_employt  
usd_Revenue_lastmonth usd_Profit_lastmonth usd_assets usd_capital	/* Financials (US$) */
any_account banks_any_account banksonly_bus_account account_used_only_business rosca_sacco  save_home borrowed_in_past  /* Financial services */
bank_loan usd_debt_outst_include mix_bus_hh  time_to_nearestbank  	
paidcitycouncilmktfee benefits_reg inspected_municipality  /* Formality */
Asked_for_bribe sexuallyHarassed  /* Harassment */
 ;
;
#d cr 

capture matrix drop BD

capture matrix drop BD_STARS


foreach var of varlist `BS_descriptive_TableA1' {


scalar drop _all

quietly sum `var' if round_fup==0 /* baseline descriptives*/

quietly scalar bin`var' = r(min) + r(max) 

if bin`var'==1 {

 sum `var' if round_fup==0 /* baseline descriptives*/

quietly scalar tmean`var' = round(r(mean)*100,.001)
quietly scalar tsd`var' = round(r(sd)*100,.001)

 ttest `var' if round_fup==0 , by(female) /* baseline descriptives*/

quietly scalar mean1`var' =  round(r(mu_1)*100,.001)

quietly scalar mean2`var' =  round(r(mu_2)*100,.001)

}

 

else {

 sum `var'  if round_fup==0 /* baseline descriptives*/

quietly scalar tmean`var' = round(r(mean),.001)
quietly scalar tsd`var' = round(r(sd),.001)

 ttest `var' if round_fup==0 , by(female)   /* baseline descriptives*/

quietly scalar mean1`var' =  round(r(mu_1),.001)

quietly scalar mean2`var' =  round(r(mu_2),.001)


}

 

quietly scalar dif`var' = round(mean1`var' - mean2`var', .001)

quietly scalar total`var' =  r(N_1) + r(N_2)

quietly scalar pvalue`var' = round(r(p),.0001)

if pvalue`var' <= 0.01 quietly scalar `var'_stars = 1

if pvalue`var' <= 0.05 & pvalue`var' > 0.01 quietly scalar `var'_stars = 2

if pvalue`var' <= 0.1  & pvalue`var' > 0.05 quietly scalar `var'_stars = 3

if pvalue`var' > 0.1  quietly scalar `var'_stars = 0

quietly matrix BD= nullmat(BD) \ [tmean`var', tsd`var', mean1`var', mean2`var', dif`var', pvalue`var']

quietly matrix BD_STARS = nullmat(BD_STARS) \ [0, 0, 0, 0, `var'_stars, 0]

}

 

quietly matrix rownames BD = `BS_descriptive_TableA1'

quietly matrix colnames BD = TotalMean TotalSD Male Female Difference Pvalue

matrix list BD

xml_tab BD using "$analysis\TableA1.xml", format(S2100, N2301, N2301, N2301, N2301, N2301, N2303 ) sheet("Table A1") replace



* Table A2: Attrition and Business closure

tab F_no_attrition round_fup, m
tab F_has_business round_fup, m
tab F_closure round_fup, m


* Atrition
* By follow-up
forvalues r=1/4 {
reg F_attrition treat1_BR treat2_BR_TPIN treat3_BR_Bank strata_* if round_fup==`r', r
eststo

test treat1_BR=treat2_BR_TPIN
estadd scalar pvalue1=r(p)
test treat1_BR=treat3_BR_Bank
estadd scalar pvalue2=r(p)
test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0
estadd scalar pvalue3=r(p)
sum F_attrition if treatment==4 & round_fup==`r'
estadd scalar mean1=r(mean)
}

* All follow-ups
reg F_attrition treat1_BR treat2_BR_TPIN treat3_BR_Bank FU1 FU2 FU3 strata_*, r
eststo

test treat1_BR=treat2_BR_TPIN
estadd scalar pvalue1=r(p)
test treat1_BR=treat3_BR_Bank
estadd scalar pvalue2=r(p)
test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0
estadd scalar pvalue3=r(p)
sum F_attrition if treatment==4
estadd scalar mean1=r(mean)


* Closure
* By follow-up
forvalues r=1/4 {
reg F_closure treat1_BR treat2_BR_TPIN treat3_BR_Bank strata_* if round_fup==`r', r
eststo

test treat1_BR=treat2_BR_TPIN
estadd scalar pvalue1=r(p)
test treat1_BR=treat3_BR_Bank
estadd scalar pvalue2=r(p)
test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0
estadd scalar pvalue3=r(p)
sum F_closure if treatment==4 & round_fup==`r'
estadd scalar mean1=r(mean)
}

* All follow-ups
reg F_closure treat1_BR treat2_BR_TPIN treat3_BR_Bank FU1 FU2 FU3 strata_*, r
eststo

test treat1_BR=treat2_BR_TPIN
estadd scalar pvalue1=r(p)
test treat1_BR=treat3_BR_Bank
estadd scalar pvalue2=r(p)
test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0
estadd scalar pvalue3=r(p)
sum F_closure if treatment==4
estadd scalar mean1=r(mean)

* We save estimation results			
esttab,  stats(mean1 N pvalue1 pvalue2 pvalue3 ) se star(* 0.10 ** 0.05 *** 0.01)
esttab using "$analysis\TableA2.csv", stats(mean1 N pvalue1 pvalue2 pvalue3 ) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear


*** Table A3: Impacts over time on having BRC 
			

			* Each Follow-up rounds
			forvalues r=1/4 {	
			
			* Firms considered
			preserve
			keep if round_fup==`r'

			xi: areg F_has_BRC  treat1_BR treat2_BR_TPIN treat3_BR_Bank has_BRC missBShas_BRC if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
			eststo
			
			* Control group mean
			sum F_has_BRC if treatment==4 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)	
				
			*q-values
			parmest, norestore
			qqvalue p, method(simes) qvalue(qvalhas_BRC)
			rename p p_has_BRC
			mkmat estimate stderr p_has_BRC qvalhas_BRC
			matrix TEMP1 =estimate, stderr, p_has_BRC, qvalhas_BRC
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_has_BRC = TEMP2[1..4, 1]
			matrix list M_has_BRC
			matrix M_has_BRC = M_has_BRC\TEMP2[1..4, 2]
			matrix M_has_BRC = M_has_BRC\TEMP2[1..4, 3]
			matrix list M_has_BRC 
			matrix colnames M_has_BRC = has_BRC
			matrix TABLEA3Q = nullmat(TABLEA3Q), M_has_BRC
			mat drop estimate stderr p_has_BRC qvalhas_BRC TEMP1 TEMP2 M_has_BRC
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
	
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
	
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)
			
	        restore
			}

			* All Follow-up rounds
			
			* Firms considered
			xi: areg F_has_BRC  treat1_BR treat2_BR_TPIN treat3_BR_Bank has_BRC missBShas_BRC FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0 , a(groupstrata) cluster(id) robust
			eststo
			
			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qvalhas_BRC)
			rename p p_has_BRC
			mkmat estimate stderr p_has_BRC qvalhas_BRC
			matrix TEMP1 =estimate, stderr, p_has_BRC, qvalhas_BRC
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_has_BRC = TEMP2[1..4, 1]
			matrix list M_has_BRC
			matrix M_has_BRC = M_has_BRC\TEMP2[1..4, 2]
			matrix M_has_BRC = M_has_BRC\TEMP2[1..4, 3]
			matrix list M_has_BRC 
			matrix colnames M_has_BRC = has_BRC
			matrix TABLEA3Q = TABLEA3Q, M_has_BRC 
			mat drop estimate stderr p_has_BRC qvalhas_BRC TEMP1 TEMP2 M_has_BRC
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
		
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)

			sum F_has_BRC  if treatment==4 & F_no_attrition==1 & round_fup!=0 
			estadd scalar mean1=r(mean)

			* Testing equality of treatment effects over time (i.e. that the effect is the same in round 1, round 2, round 3, and round 4).
			/* Y(i,t) = b0 + b1*FU1*BRC(i) + b2*FU2*BRC(i)+ b3*FU3*BRC(i) + b4*FU4*BRC(i) + 
				  c1*FU1*[BRC+TPIN](i) + c2*FU2* [BRC+TPIN](i)+ c3*FU3*[BRC+TPIN](i) + c4*FU4*[BRC+TPIN](i) + 
				  d1*FU1*[BRC+BBA](i) + d2*FU2* [BRC+BBA](i)+ d3*FU3*[BRC+BBA](i) + d4*FU4*[BRC+BBA](i) +
				  f2*FU2 + f3*FU3 + f4*FU4 + g*Strata dummies + h*BaselineY(i,t) + j * missingBSdatadummy + e(i,t) */

			# d ;
				 xi: areg F_has_BRC  FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 has_BRC   missBShas_BRC  if F_no_attrition==1 & round_fup!=0, ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)
			
			
* We save estimation results			
esttab,  stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) se star(* 0.10 ** 0.05 *** 0.01)
esttab using "$analysis\TableA3.csv", stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) replace

xml_tab TABLEA3Q using "$analysis\qvalues\TableA3q-values.xml", format(S2100, N2303, N2303, N2303, N2303, N2303, N2303) sheet("TableA3") replace

eststo clear			


*** Table A4: Impacts on Access to Financial services

/* for some financial and savings outcomes (z-score, Has a bank account, Does not save at home, Does not save in ROSCA or SACCO,Saves at bank)
we consider only firms didn't closed */

* All Follow-up rounds
* z-score
		xi: areg avg_z_hyp_FS_FU  treat1_BR treat2_BR_TPIN treat3_BR_Bank avg_z_hyp_FS_BS  missBSavg_z_hyp_FS FU1 FU2 FU3 if closure==0 & F_no_attrition==1 & round_fup!=0 , a(groupstrata) cluster(id) robust
		eststo
		
		*q-values
		preserve
		parmest, norestore
		qqvalue p, method(simes) qvalue(qvalz_hyp_FS)
		rename p p_z_hyp_FS
		mkmat estimate stderr p_z_hyp_FS qvalz_hyp_FS
		matrix TEMP1 =estimate, stderr, p_z_hyp_FS, qvalz_hyp_FS
		matrix list TEMP1
		matrix TEMP2= TEMP1[1..3, 1..4]'
		matrix list TEMP2
		matrix TABLEA4Q = TEMP2[1..4, 1]
		matrix list TABLEA4Q
		matrix TABLEA4Q = TABLEA4Q\TEMP2[1..4, 2]
		matrix TABLEA4Q = TABLEA4Q\TEMP2[1..4, 3]
		matrix list TABLEA4Q 
		matrix colnames TABLEA4Q = avg_z_hyp_z_hyp_FS_FU
		mat drop estimate stderr p_z_hyp_FS qvalz_hyp_FS TEMP1 TEMP2
	    restore
			
		* Testing that all treatments are jointly equal in treatment effect. 
		test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
		estadd scalar pvalue1=r(p)
	
		test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
		estadd scalar pvalue2=r(p)
		
		test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
		estadd scalar pvalue3=r(p)
		
		* Testing that all treatment effects are jointly zero.
		test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
		estadd scalar pvalue4=r(p)
		
		* Control group mean
		sum avg_z_hyp_FS_FU  if treatment==4  & closure==0 & F_no_attrition==1 & round_fup!=0
		estadd scalar mean1=r(mean)
		
* Testing equality of treatment effects over time (i.e. that the effect is the same in round 1, round 2, round 3, and round 4).
  /* Y(i,t) = b0 + b1*FU1*BRC(i) + b2*FU2*BRC(i)+ b3*FU3*BRC(i) + b4*FU4*BRC(i) + 
				  c1*FU1*[BRC+TPIN](i) + c2*FU2* [BRC+TPIN](i)+ c3*FU3*[BRC+TPIN](i) + c4*FU4*[BRC+TPIN](i) + 
				  d1*FU1*[BRC+BBA](i) + d2*FU2* [BRC+BBA](i)+ d3*FU3*[BRC+BBA](i) + d4*FU4*[BRC+BBA](i) +
				  f2*FU2 + f3*FU3 + f4*FU4 + g*Strata dummies + h*BaselineY(i,t) + j * missingBSdatadummy + e(i,t) */

			# d ;
				 xi: areg avg_z_hyp_FS_FU FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 avg_z_hyp_FS_BS  missBSavg_z_hyp_FS if closure==0 & F_no_attrition==1 & round_fup!=0, ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)
			
* Has a bank account
			
xi: areg F_banks_any_account  treat1_BR treat2_BR_TPIN treat3_BR_Bank banks_any_account missBSbanks_any_account FU1 FU2 FU3 if closure==0 & F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
			eststo
			
			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qvalbanks_any_account)
			rename p p_banks_any_account
			mkmat estimate stderr p_banks_any_account qvalbanks_any_account
			matrix TEMP1 =estimate, stderr, p_banks_any_account, qvalbanks_any_account
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_banks_any_account = TEMP2[1..4, 1]
			matrix list M_banks_any_account
			matrix M_banks_any_account = M_banks_any_account\TEMP2[1..4, 2]
			matrix M_banks_any_account = M_banks_any_account\TEMP2[1..4, 3]
			matrix list M_banks_any_account 
			matrix colnames M_banks_any_account = banks_any_account
			matrix TABLEA4Q = TABLEA4Q, M_banks_any_account 
			mat drop estimate stderr p_banks_any_account qvalbanks_any_account TEMP1 TEMP2 M_banks_any_account
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
		
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)
			
			* Control group mean
			sum F_banks_any_account  if treatment==4 & closure==0 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)

* Testing equality of treatment effects over time (i.e. that the effect is the same in round 1, round 2, round 3, and round 4).
  /* Y(i,t) = b0 + b1*FU1*BRC(i) + b2*FU2*BRC(i)+ b3*FU3*BRC(i) + b4*FU4*BRC(i) + 
				  c1*FU1*[BRC+TPIN](i) + c2*FU2* [BRC+TPIN](i)+ c3*FU3*[BRC+TPIN](i) + c4*FU4*[BRC+TPIN](i) + 
				  d1*FU1*[BRC+BBA](i) + d2*FU2* [BRC+BBA](i)+ d3*FU3*[BRC+BBA](i) + d4*FU4*[BRC+BBA](i) +
				  f2*FU2 + f3*FU3 + f4*FU4 + g*Strata dummies + h*BaselineY(i,t) + j * missingBSdatadummy + e(i,t) */
			
			# d ;
				 xi: areg F_banks_any_account FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 banks_any_account missBSbanks_any_account if closure==0 & F_no_attrition==1 & round_fup!=0, ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)	
			
			
* Has a business bank account
* Used an account just for business purposes	

foreach var of varlist banksonly_bus_account  account_used_only_business {
			xi: areg F_`var'  treat1_BR treat2_BR_TPIN treat3_BR_Bank `var' missBS`var' FU1 FU2 FU3 if F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
			eststo

			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qval`var')
			rename p p_`var'
			mkmat estimate stderr p_`var' qval`var'
			matrix TEMP1 =estimate, stderr, p_`var', qval`var'
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_`var' = TEMP2[1..4, 1]
			matrix list M_`var'
			matrix M_`var' = M_`var'\TEMP2[1..4, 2]
			matrix M_`var' = M_`var'\TEMP2[1..4, 3]
			matrix list M_`var' 
			matrix colnames M_`var' = `var'
			matrix TABLEA4Q = TABLEA4Q, M_`var' 
			mat drop estimate stderr p_`var' qval`var' TEMP1 TEMP2 M_`var'
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
		
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)
			
			* Control group mean
			sum F_`var'  if treatment==4 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)

* Testing equality of treatment effects over time (i.e. that the effect is the same in round 1, round 2, round 3, and round 4).
  /* Y(i,t) = b0 + b1*FU1*BRC(i) + b2*FU2*BRC(i)+ b3*FU3*BRC(i) + b4*FU4*BRC(i) + 
				  c1*FU1*[BRC+TPIN](i) + c2*FU2* [BRC+TPIN](i)+ c3*FU3*[BRC+TPIN](i) + c4*FU4*[BRC+TPIN](i) + 
				  d1*FU1*[BRC+BBA](i) + d2*FU2* [BRC+BBA](i)+ d3*FU3*[BRC+BBA](i) + d4*FU4*[BRC+BBA](i) +
				  f2*FU2 + f3*FU3 + f4*FU4 + g*Strata dummies + h*BaselineY(i,t) + j * missingBSdatadummy + e(i,t) */
			
			# d ;
				 xi: areg F_`var' FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 `var' missBS`var' if F_no_attrition==1 & round_fup!=0, ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)	
		}	
			
			

* Does not save at home
* Does not save in ROSCA or SACCO
* Saves at bank

foreach var of varlist no_save_home no_rosca_sacco banks_saving  {
			xi: areg F_`var'  treat1_BR treat2_BR_TPIN treat3_BR_Bank `var' missBS`var' FU1 FU2 FU3 if closure==0 & F_no_attrition==1 & round_fup!=0, a(groupstrata) cluster(id) robust
			eststo

			*q-values
			preserve
			parmest, norestore
			qqvalue p, method(simes) qvalue(qval`var')
			rename p p_`var'
			mkmat estimate stderr p_`var' qval`var'
			matrix TEMP1 =estimate, stderr, p_`var', qval`var'
			matrix list TEMP1
			matrix TEMP2= TEMP1[1..3, 1..4]'
			matrix list TEMP2
			matrix M_`var' = TEMP2[1..4, 1]
			matrix list M_`var'
			matrix M_`var' = M_`var'\TEMP2[1..4, 2]
			matrix M_`var' = M_`var'\TEMP2[1..4, 3]
			matrix list M_`var' 
			matrix colnames M_`var' = `var'
			matrix TABLEA4Q = TABLEA4Q, M_`var' 
			mat drop estimate stderr p_`var' qval`var' TEMP1 TEMP2 M_`var'
			restore
			
			* Testing that all treatments are jointly equal in treatment effect. 
			test treat1_BR=treat2_BR_TPIN  /*treat1=treat2*/
			estadd scalar pvalue1=r(p)
		
			test treat1_BR=treat3_BR_Bank  /*treat1=treat3*/
			estadd scalar pvalue2=r(p)
			
			test treat2_BR_TPIN=treat3_BR_Bank  /*treat2=treat3*/
			estadd scalar pvalue3=r(p)
			
			* Testing that all treatment effects are jointly zero.
			test treat1_BR=treat2_BR_TPIN=treat3_BR_Bank=0   /*treat1=treat2=treat3=0*/
			estadd scalar pvalue4=r(p)
			
			* Control group mean
			sum F_`var'  if treatment==4 & closure==0 & F_no_attrition==1 & round_fup!=0
			estadd scalar mean1=r(mean)

* Testing equality of treatment effects over time (i.e. that the effect is the same in round 1, round 2, round 3, and round 4).
  /* Y(i,t) = b0 + b1*FU1*BRC(i) + b2*FU2*BRC(i)+ b3*FU3*BRC(i) + b4*FU4*BRC(i) + 
				  c1*FU1*[BRC+TPIN](i) + c2*FU2* [BRC+TPIN](i)+ c3*FU3*[BRC+TPIN](i) + c4*FU4*[BRC+TPIN](i) + 
				  d1*FU1*[BRC+BBA](i) + d2*FU2* [BRC+BBA](i)+ d3*FU3*[BRC+BBA](i) + d4*FU4*[BRC+BBA](i) +
				  f2*FU2 + f3*FU3 + f4*FU4 + g*Strata dummies + h*BaselineY(i,t) + j * missingBSdatadummy + e(i,t) */
			
			# d ;
				 xi: areg F_`var' FU1treat1_BR  FU2treat1_BR  FU3treat1_BR  FU4treat1_BR 
									 FU1treat2_BR_TPIN FU2treat2_BR_TPIN FU3treat2_BR_TPIN FU4treat2_BR_TPIN 
									 FU1treat3_BR_Bank FU2treat3_BR_Bank  FU3treat3_BR_Bank  FU4treat3_BR_Bank  
									 FU1 FU2 FU3 `var' missBS`var' if closure==0 & F_no_attrition==1 & round_fup!=0, ab(groupstrata) cluster(id) robust ;	 
			eststo; 
			# d cr ;						 

			test FU1treat1_BR = FU2treat1_BR = FU3treat1_BR = FU4treat1_BR
			estadd scalar pvalue5=r(p)
			test FU1treat2_BR_TPIN = FU2treat2_BR_TPIN = FU3treat2_BR_TPIN = FU4treat2_BR_TPIN 
			estadd scalar pvalue6=r(p)
			test FU1treat3_BR_Bank = FU2treat3_BR_Bank = FU3treat3_BR_Bank = FU4treat3_BR_Bank
			estadd scalar pvalue7=r(p)	
		}	


* We save estimation results			
esttab,  stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) se star(* 0.10 ** 0.05 *** 0.01)
esttab using "$analysis\TableA4.csv", stats(mean1 N pvalue1 pvalue2 pvalue3 pvalue4 pvalue5 pvalue6 pvalue7 ) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) replace

xml_tab TABLEA4Q using "$analysis\qvalues\TableA4q-values.xml", format(S2100, N2303, N2303, N2303, N2303, N2303, N2303, N2303) sheet("TableA4") replace

eststo clear
			

	

